[−][src]Struct git_global::Repo
A git repository, represented by the full path to its base directory.
Methods
impl Repo[src]
pub fn new(path: String) -> Repo[src]
pub fn as_git2_repo(&self) -> Option<Repository>[src]
Returns the git2::Repository equivalent of this repo.
pub fn path(&self) -> String[src]
Returns the full path to the repo as a String.