Module git_global::subcommands
source · Expand description
Subcommand implementations and dispatch function run().
Modules
- The
aheadsubcommand: shows repositories that have commits not pushed to a remote - The
infosubcommand: shows metadata about the git-global installation. - The
install-manpagesubcommand: attempts to install a man page. - The
listsubcommand: lists all repos known to git-global. - The
scansubcommand: scans the filesystem for git repos. - The
stagedsubcommand: showsgit status -sfor staged changes in all known repos with such changes. - The
stashedsubcommand: shows stash list for all known repos with stashes - The
statussubcommand: showsgit status -sfor all known repos with any changes to the index or working directory. - The
unstagedsubcommand: showsgit status -sfor unstaged changes in all known repos with such changes.
Functions
- Return the list of all subcommand names and descriptions.
- Run a subcommand, returning a
Report.