Function git_global::subcommands::list::execute
source · pub fn execute(config: Config) -> Result<Report>Expand description
Forces the display of each repo path, without any extra output.
pub fn execute(config: Config) -> Result<Report>Forces the display of each repo path, without any extra output.