Module scan

Module scan 

The scan subcommand: scans the filesystem for git repos.

By default, the user’s home directory is walked, but this starting point can be configured in ~/.gitconfig:

$ git config --global global.basedir /some/path

Additional directories can be scanned by passing them as arguments:

$ git global scan /extra/path1 /extra/path2

The scan subcommand caches the list of git repos paths it finds, and can be rerun at any time to refresh the list.

Functions

execute
Clears the cache, forces a rescan, and says how many repos were found.