Function git_global::subcommands::scan::execute
source · pub fn execute(config: Config) -> Result<Report>Expand description
Clears the cache, forces a rescan, and says how many repos were found.
pub fn execute(config: Config) -> Result<Report>Clears the cache, forces a rescan, and says how many repos were found.