Module git_global::subcommands::stashed
source · Expand description
The stashed subcommand: shows stash list for all known repos with stashes
Functions
- Runs the
stashedsubcommand.
The stashed subcommand: shows stash list for all known repos with stashes
stashed subcommand.