[−][src]Struct git_global::Report
A report containing the results of a git-global subcommand.
Contains overall messages and per-repo messages.
Methods
impl Report[src]
pub fn new(repos: &Vec<Repo>) -> Report[src]
Create a new Report for the given Repos..
pub fn pad_repo_output(&mut self)[src]
Declares the desire to separate output when showing per-repo messages.
Sets flag that indicates a blank line should be inserted between messages for different repos when printing per-repo output.
pub fn add_message(&mut self, message: String)[src]
Adds a message that applies to the overall operation.
pub fn add_repo_message(&mut self, repo: &Repo, data_line: String)[src]
Adds a message that applies to the given repo.
pub fn print<W: Write>(&self, writer: &mut W)[src]
Writes all result messages to the given writer, as text.
pub fn print_json<W: Write>(&self, writer: &mut W)[src]
Writes all result messages to the given writer, as JSON.